import _defineProperty from "@babel/runtime/helpers/esm/defineProperty";
import _JSXStyle from "styled-jsx/style";
import React from "react";
import { Button, Ref } from "semantic-ui-react";
import { PureComponent, createRef } from "react";
import { bool, func, node, string } from "prop-types";
import { isNil } from "lodash";
import { momentObj as momentType } from "react-moment-proptypes";
import cx from "classnames";
export class DateRangePickerInput extends PureComponent {
  constructor() {
    super(...arguments);

    _defineProperty(this, "_clearButtonRef", createRef());

    _defineProperty(this, "_containerRef", createRef());

    _defineProperty(this, "handleClick", event => {
      const {
        onClick,
        allowClear
      } = this.props;
      let canPropagate = true;

      if (allowClear) {
        canPropagate = !this._clearButtonRef.current.contains(event.target);
      }

      if (canPropagate) {
        onClick(event, this.props);
      }
    });

    _defineProperty(this, "handleClear", event => {
      const {
        onClear
      } = this.props;
      onClear(event, this.props);
    });
  }

  getValue() {
    const {
      startDate,
      endDate,
      placeholder,
      rangeFormat,
      dateFormat
    } = this.props;

    const result = (text, isPlaceholder) => ({
      text,
      isPlaceholder
    });

    if (!isNil(startDate)) {
      if (!isNil(endDate)) {
        return result(rangeFormat.replace("{startDate}", startDate.format(dateFormat)).replace("{endDate}", endDate.format(dateFormat)), false);
      }

      return result(startDate.format(dateFormat));
    }

    return result(placeholder, true);
  }

  getCssClasses(value) {
    const {
      disabled,
      open,
      className
    } = this.props;
    const openedClasses = open && !disabled ? " b--marine-600 marine-600" : " b--cloud-200 marine-200";
    const disabledClasses = cx({
      " bg-cloud-100 cloud-400 crsr-not-allowed": disabled
    });
    const placeholderClasses = cx({
      " marine-700": !value.isPlaceholder && !disabled
    });
    const defaultClasses = "input pv3 ph4 ba outline-0 f6 h9 br2 flex items-center".concat(openedClasses).concat(placeholderClasses).concat(disabledClasses);
    return isNil(className) ? defaultClasses : "".concat(defaultClasses, " ").concat(className);
  }

  renderIcon() {
    const {
      icon,
      disabledIcon
    } = this.props;
    const {
      disabled
    } = this.props;
    return disabled ? disabledIcon : icon;
  }

  renderClearButton(value) {
    const {
      allowClear,
      clearIcon,
      disabled,
      open
    } = this.props;

    if (!allowClear) {
      return null;
    }

    return React.createElement("div", {
      className: cx({
        dn: value.isPlaceholder || disabled || open
      })
    }, React.createElement(Ref, {
      innerRef: this._clearButtonRef
    }, React.createElement(Button, {
      circular: true,
      size: "mini",
      primary: true,
      icon: true,
      className: "transparent",
      onClick: this.handleClear
    }, clearIcon)));
  }

  render() {
    const {
      onKeyDown,
      disabled
    } = this.props;
    const value = this.getValue();
    return React.createElement("div", {
      onClick: this.handleClick,
      onKeyDown: onKeyDown,
      tabIndex: disabled ? null : "0",
      autoComplete: "off",
      disabled: disabled,
      ref: this._containerRef,
      className: "jsx-2462695752" + " " + (this.getCssClasses(value) || "")
    }, this.renderIcon(), React.createElement("span", {
      className: "jsx-2462695752" + " " + "flex-grow-1 ml4"
    }, value.text), this.renderClearButton(value), React.createElement(_JSXStyle, {
      id: "2462695752"
    }, [".input.jsx-2462695752:not(\"disabled\"){cursor:text;}", ".input.jsx-2462695752:focus{border:1px solid var(--marine-700);color:var(--marine-700);}"]));
  } // This method is part of the component API and is intended to be used externally


  getHeight() {
    return this._containerRef.current.offsetHeight;
  }

}