import _defineProperty from "@babel/runtime/helpers/esm/defineProperty";
import React from "react";
import "react-dates/initialize";
import "react-dates/lib/css/_datepicker.css";
import { ANCHOR_CENTER, ANCHOR_LEFT, ANCHOR_RIGHT, OPEN_DOWN, OPEN_UP } from "./directions";
import { ArgumentError, AutoControlledPureComponent, KEYS, getAutoControlledStateFromProps } from "@orbit-ui/react-components-shared";
import { ArrowIcon, ClearIcon, InputCalendarIcon, PresetsCalendarIcon } from "@orbit-ui/icons";
import { DateRangePickerButtons } from "./date-range-picker-buttons";
import { DateRangePickerCalendar } from "./date-range-picker-calendar";
import { DateRangePickerInput } from "./date-range-picker-input";
import { DateRangePickerPresets } from "./date-range-picker-presets";
import { FadeIn } from "./fade-in";
import { PRESET_SHAPE } from "./presets";
import { Popup } from "@orbit-ui/react-popup";
import { arrayOf, bool, func, node, oneOf, oneOfType, shape, string } from "prop-types";
import { cloneElement } from "react";
import { isNil } from "lodash";
import { momentObj as momentType } from "react-moment-proptypes";
export class DateRangePicker extends AutoControlledPureComponent {
  constructor() {
    super(...arguments);

    _defineProperty(this, "state", {
      startDate: null,
      endDate: null,
      selectedStartDate: null,
      selectedEndDate: null,
      selectedPresetName: null,
      open: false,
      inputHeight: 0
    });

    _defineProperty(this, "handleInputClick", event => {
      const {
        open
      } = this.state;

      if (!open) {
        this.toggleCalendarVisibility(event);
      }
    });

    _defineProperty(this, "handleInputClear", event => {
      const {
        onDatesChange
      } = this.props;
      this.trySetAutoControlledStateValue({
        startDate: null
      });
      this.trySetAutoControlledStateValue({
        endDate: null
      });
      this.setState({
        selectedStartDate: null,
        selectedEndDate: null,
        selectedPresetName: null
      });
      onDatesChange(event, null, null, null, this.props);
    });

    _defineProperty(this, "handleInputKeyDown", event => {
      const key = event.keyCode;

      if (key === KEYS.space || key === KEYS.enter) {
        if (key === KEYS.space) {
          event.preventDefault();
        }

        this.toggleCalendarVisibility(event);
      }
    });

    _defineProperty(this, "handlePopupClose", event => {
      const {
        startDate,
        endDate
      } = this.state;
      this.setState({
        selectedStartDate: startDate,
        selectedEndDate: endDate,
        selectedPresetName: null
      });
      this.toggleCalendarVisibility(event);
    });

    _defineProperty(this, "handleCalendarDatesChange", (startDate, endDate, presetName) => {
      this.setState({
        selectedStartDate: startDate,
        selectedEndDate: endDate,
        selectedPresetName: presetName
      });
    });

    _defineProperty(this, "handleCalendarApply", event => {
      const {
        onDatesChange
      } = this.props;
      const {
        selectedStartDate,
        selectedEndDate,
        selectedPresetName
      } = this.state;
      this.toggleCalendarVisibility(event);
      this.trySetAutoControlledStateValue({
        startDate: selectedStartDate
      });
      this.trySetAutoControlledStateValue({
        endDate: selectedEndDate
      });
      onDatesChange(event, selectedStartDate, selectedEndDate, selectedPresetName, this.props);
    });

    _defineProperty(this, "setInputHeight", ref => {
      if (!isNil(ref)) {
        setTimeout(() => {
          this.setState({
            inputHeight: ref.getHeight()
          });
        }, 0);
      }
    });
  }

  componentDidMount() {
    const {
      minDate,
      maxDate
    } = this.props;

    if (!isNil(minDate) && !isNil(maxDate)) {
      if (minDate.isSameOrAfter(maxDate)) {
        throw new ArgumentError("DateRangePicker - \"minDate\" must be before \"maxDate\".");
      }
    }
  }

  static getDerivedStateFromProps(props, state) {
    return getAutoControlledStateFromProps(props, state, DateRangePicker.autoControlledProps, (_ref) => {
      let {
        startDate,
        endDate
      } = _ref;
      return {
        selectedStartDate: startDate,
        selectedEndDate: endDate
      };
    });
  }

  toggleCalendarVisibility(event) {
    const {
      onVisibilityChange
    } = this.props;
    const {
      open
    } = this.state;
    this.trySetAutoControlledStateValue({
      open: !open
    });

    if (!isNil(onVisibilityChange)) {
      onVisibilityChange(event, !open, this.props);
    }
  }

  getAnchorDirectionProps() {
    const {
      anchorDirection,
      anchorOffset
    } = this.props;

    if (anchorDirection === ANCHOR_LEFT) {
      return {
        left: "0px",
        offsetX: anchorOffset
      };
    } else if (anchorDirection === ANCHOR_RIGHT) {
      return {
        right: "0px",
        offsetX: anchorOffset
      };
    } else if (anchorDirection === ANCHOR_CENTER) {
      return {
        left: "50%",
        offsetX: "calc(-50% + ".concat(anchorOffset)
      };
    }

    return {};
  }

  getOpenDirectionProps() {
    const {
      openDirection
    } = this.props;
    const {
      inputHeight
    } = this.state;

    if (openDirection === OPEN_DOWN) {
      return {
        top: "0px"
      };
    } else if (openDirection === OPEN_UP) {
      return {
        bottom: "".concat(inputHeight, "px")
      };
    }

    return {};
  }

  getCssClasses() {
    const {
      className
    } = this.props;
    const defaultClasses = "relative";
    return isNil(className) ? defaultClasses : "".concat(defaultClasses, " ").concat(className);
  }

  renderInput() {
    const {
      input,
      inputIcon,
      disabledInputIcon,
      inputClearIcon,
      allowClear,
      placeholder,
      rangeFormat,
      dateFormat,
      disabled
    } = this.props;
    const {
      selectedStartDate,
      selectedEndDate,
      open
    } = this.state;
    return cloneElement(input, {
      startDate: selectedStartDate,
      endDate: selectedEndDate,
      onClick: this.handleInputClick,
      onClear: this.handleInputClear,
      onKeyDown: this.handleInputKeyDown,
      allowClear,
      placeholder,
      rangeFormat,
      dateFormat,
      icon: inputIcon,
      disabledIcon: disabledInputIcon,
      clearIcon: inputClearIcon,
      disabled: disabled,
      open: open,
      ref: this.setInputHeight
    });
  }

  renderCalendar() {
    const {
      allowSingleDateSelection,
      allowClear,
      minDate,
      maxDate,
      initialVisibleMonth,
      openDirection,
      calendar,
      navPrevIcon,
      navNextIcon,
      presetsComponent,
      presets,
      presetsIcon,
      buttons,
      clearText,
      applyText
    } = this.props;
    const {
      selectedStartDate,
      selectedEndDate
    } = this.state;
    return cloneElement(calendar, {
      startDate: selectedStartDate,
      endDate: selectedEndDate,
      onDatesChange: this.handleCalendarDatesChange,
      onApply: this.handleCalendarApply,
      allowSingleDateSelection,
      allowClear,
      minDate,
      maxDate,
      initialVisibleMonth,
      openDirection,
      presetsComponent,
      presets,
      presetsIcon,
      buttons,
      navPrevIcon,
      navNextIcon,
      clearText,
      applyText
    });
  }

  render() {
    const {
      disabled
    } = this.props;
    const {
      open
    } = this.state;
    return React.createElement("div", {
      className: this.getCssClasses()
    }, this.renderInput(), !disabled ? React.createElement(FadeIn, {
      active: open,
      className: "relative z-2"
    }, React.createElement(Popup, Object.assign({
      visible: open,
      onOutsideClick: this.handlePopupClose,
      onEscapeKeyDown: this.handlePopupClose
    }, this.getAnchorDirectionProps(), this.getOpenDirectionProps()), React.createElement("div", null, this.renderCalendar()))) : null);
  }

}

_defineProperty(DateRangePicker, "propTypes", {
  startDate: momentType,
  endDate: momentType,
  defaultStartDate: momentType,
  defaultEndDate: momentType,
  onDatesChange: func.isRequired,
  onVisibilityChange: func,
  allowSingleDateSelection: bool,
  allowClear: bool,
  minDate: momentType,
  maxDate: momentType,
  initialVisibleMonth: oneOfType([momentType, func]),
  input: node,
  inputIcon: node,
  disabledInputIcon: node,
  inputClearIcon: node,
  placeholder: string,
  rangeFormat: string,
  dateFormat: string,
  anchorDirection: oneOf([ANCHOR_LEFT, ANCHOR_RIGHT, ANCHOR_CENTER]),
  anchorOffset: string,
  openDirection: oneOf([OPEN_DOWN, OPEN_UP]),
  calendar: node,
  navPrevIcon: node,
  navNextIcon: node,
  presetsComponent: node,
  presets: arrayOf(shape(PRESET_SHAPE)),
  presetsIcon: node,
  buttons: node,
  clearText: string,
  applyText: string,
  defaultOpen: bool,
  open: bool,
  disabled: bool,
  className: string
});

_defineProperty(DateRangePicker, "defaultProps", {
  allowSingleDateSelection: false,
  allowClear: true,
  input: React.createElement(DateRangePickerInput, null),
  inputIcon: React.createElement(InputCalendarIcon, {
    className: "w6 h6 fill-marine-700"
  }),
  disabledInputIcon: React.createElement(InputCalendarIcon, {
    className: "w6 h6 fill-cloud-500"
  }),
  inputClearIcon: React.createElement(ClearIcon, {
    className: "h3 w3"
  }),
  placeholder: "Pick a date2",
  rangeFormat: "{startDate} - {endDate}",
  dateFormat: "MMM Do YYYY",
  anchorDirection: ANCHOR_LEFT,
  anchorOffset: "0px",
  openDirection: OPEN_DOWN,
  calendar: React.createElement(DateRangePickerCalendar, null),
  navPrevIcon: React.createElement(ArrowIcon, {
    className: "w4 h4 rotate-180 fill-marine-500"
  }),
  navNextIcon: React.createElement(ArrowIcon, {
    className: "w4 h4 fill-marine-500"
  }),
  presetsComponent: React.createElement(DateRangePickerPresets, null),
  presets: [],
  presetsIcon: React.createElement(PresetsCalendarIcon, {
    className: "w8 h8 fill-marine-500"
  }),
  buttons: React.createElement(DateRangePickerButtons, null),
  clearText: "Clear",
  applyText: "Apply",
  disabled: false
});

_defineProperty(DateRangePicker, "autoControlledProps", ["startDate", "endDate", "open"]);

_defineProperty(DateRangePicker, "Input", DateRangePickerInput);

_defineProperty(DateRangePicker, "Calendar", DateRangePickerCalendar);

_defineProperty(DateRangePicker, "Presets", DateRangePickerPresets);

_defineProperty(DateRangePicker, "Buttons", DateRangePickerButtons);